clc;
close all;
clear;

%Keep the radius 2*lambda and number of nodes and sweep the frequency
c=299792458;
f1=[8.2e7 8.5e7 8.8e7 9.1e7 9.1414e+007 9.4e7];
f=c.*f1;
ND=1001;
lambda=1;

N=length(f1);

err_TEEF_f = zeros(1,N);
err_TEMF_f = zeros(1,N);
err_TMEF_f = zeros(1,N);

%Using conjugate solver to find accuracy
for i=1:N
    [I_1,sigma_1,phi_1,time,iter]=te_wave_EFIE(2*lambda,ND,f(i),'conjgr');
    [I_2,sigma_2,phi_2,time,iter]=te_wave_MFIE(2*lambda,ND,f(i),'conjgr');
    [Ia1,bsew1]=te_analytical(2*lambda,phi_1(1:end-1), f(i));
    [Ia2,bsew2]=te_analytical(2*lambda,phi_2, f(i));

    err_TEEF_f(i) = norm(I_1 - Ia1)/norm(Ia1);
    err_TEMF_f(i) = norm(I_2 - Ia2)/norm(Ia2); 
    
    [I_3,sigma_3,phi_3,time,iter]=tm_wave_EFIE(2*lambda,ND,f(i),'conjgr');
    [Ia_2,bsew_2]=tm_analytical(2*lambda,phi_3,f(i)); 

    err_TMEF_f(i) = norm(I_3 - Ia_2)/norm(Ia_2);    
end

save TestFrequencySweeping.mat;

myPlot2=figure;
plot(f, err_TEEF_f, '-or');
hold on
plot(f, err_TEMF_f, '-+b');
hold on
plot(f, err_TMEF_f, '-*k');
set(gca, 'YScale','log');
set(gca, 'XScale','log');
xlabel('Frequency (Hz)')
ylabel('Error')
xlim([2E6 1E9])
ylim([1E-7 1])
legend('TE EFIE','TE MFIE', 'TM EFIE')
set(myPlot2,'Position',[400, 400,400,250])
grid on

L = 2*2*lambda*sin(pi/ND);
tlambda=c./f;
myPlot3=figure;
plot(L./tlambda, err_TEEF_f, '-or');
hold on
plot(L./tlambda, err_TEMF_f, '-+b');
hold on
plot(L./tlambda, err_TMEF_f, '-*k');
set(gca, 'YScale','log');
set(gca, 'XScale','log');
xlabel('Segment length/\lambda')
ylabel('Error')
%xlim([2E6 1E9])
ylim([1E-7 1])
legend('TE EFIE','TE MFIE', 'TM EFIE')
set(myPlot3,'Position',[400, 400,400,250])
grid on