clc;
close all;
clear;

%Keep the radius size and number of nodes and sweep the frequency
c=299792458;
f=c;
lambda=c/f;

r=[0.2:0.2:1 2:2:20]*lambda;

N0=1001;
L0=2*r(1)*sin(pi/N0);

N=length(r);

err_TEEF_d = zeros(1,N);
err_TEMF_d = zeros(1,N);
err_TMEF_d = zeros(1,N);

%Using conjugate solver to find accuracy
for i=1:N
    %ND = ceil(pi/asin(L0/2/r(i)));
    ND=N0;
    [I_1,sigma_1,phi_1,time,iter]=te_wave_EFIE(r(i),ND,f,'conjgr');
    [I_2,sigma_2,phi_2,time,iter]=te_wave_MFIE(r(i),ND,f,'conjgr');
    [Ia1,bsew1]=te_analytical(r(i),phi_1(1:end-1), f);
    [Ia2,bsew2]=te_analytical(r(i),phi_2, f);

    err_TEEF_d(i) = norm(I_1 - Ia1)/norm(Ia1);
    err_TEMF_d(i) = norm(I_2 - Ia2)/norm(Ia2); 
    
    [I_3,sigma_3,phi_3,time,iter]=tm_wave_EFIE(r(i),ND,f,'conjgr');
    [Ia_2,bsew_2]=tm_analytical(r(i),phi_3,f); 

    err_TMEF_d(i) = norm(I_3 - Ia_2)/norm(Ia_2);    
end

save TestRadiusVariation.mat;

myPlot2=figure;
plot(r/lambda, err_TEEF_d, '-or');
hold on
plot(r/lambda, err_TEMF_d, '-+b');
hold on
plot(r/lambda, err_TMEF_d, '-*k');
set(gca, 'YScale','log');
set(gca, 'XScale','log');
xlabel('Radius (\lambda)')
ylabel('Error')
legend('TE EFIE','TE MFIE', 'TM EFIE')
set(myPlot2,'Position',[400, 400,400,250])
grid on