%   Test CPU time and accuracy vs. number of nodes
clear
clc
close all;

nodes = 161:100:1000;
N = length(nodes);
time_direct = zeros(1,N);
time_conjgr = zeros(1,N);
iter_conjgr = zeros(1,N);
err_direct = zeros(1,N);
err_conjgr = zeros(1,N);

c=299792458;
f=c;
lambda=c/f;

for i=1:N
    [I_1,sigma_1,phi_1,time_direct(i),iter]=te_wave_EFIE(2*lambda,nodes(i),f,'direct');
    [I_2,sigma_2,phi_2,time_conjgr(i),iter_conjgr(i)]=te_wave_EFIE(2*lambda,nodes(i),f,'conjgr');
    [Ia,bsew]=te_analytical(2*lambda,phi_1, f(i));

    err_direct(i) = norm(I_1 - Ia)/norm(Ia);
    err_conjgr(i) = norm(I_2 - Ia)/norm(Ia);    
end

myPlot1=figure
loglog(nodes, time_direct, 'k-o');
hold on
loglog(nodes, time_conjgr, 'r-*');
xlabel('Number of nodes')
ylabel('CPU time (s)')
legend('Direct solver','FFT solver')
set(myPlot1,'Position',[400, 400,400,250])
grid on

myPlot2=figure;
plot(nodes, err_direct, '-or');
hold on
plot(nodes, err_conjgr, '-+b');
set(gca, 'YScale','log');
set(gca, 'XScale','log');
xlabel('Number of nodes')
ylabel('Error')
legend('Direct solver','FFT solver')
set(myPlot2,'Position',[400, 400,400,250])
grid on