%   Test accuracy vs. number of nodes for all solvers
clear
clc
close all;

nodes = 201:200:3001;
N = length(nodes);

c=299792458;
f=c;
lambda=c/f;

t_TEEF = zeros(1,N);
t_TEMF = zeros(1,N);
t_TMEF = zeros(1,N);

t_TEEFD = zeros(1,N);
t_TEMFD = zeros(1,N);
t_TMEFD = zeros(1,N);

iter_TEEF = zeros(1,N);
iter_TEMF = zeros(1,N);
iter_TMEF = zeros(1,N);

err_TEEF = zeros(1,N);
err_TEMF = zeros(1,N);
err_TMEF = zeros(1,N);

%Using conjugate solver to find accuracy
for i=1:N
    [I_1,sigma_1,phi_1,t_TEEF(i),iter_TEEF(i)]=te_wave_EFIE(2*lambda,nodes(i),f,'conjgr');
    [I_2,sigma_2,phi_2,t_TEMF(i),iter_TEMF(i)]=te_wave_MFIE(2*lambda,nodes(i),f,'conjgr');
   
    [Ia1,bsew1]=te_analytical(2*lambda,phi_1(1:end-1), f);
    [Ia2,bsew2]=te_analytical(2*lambda,phi_2, f);

    err_TEEF(i) = norm(I_1 - Ia1)/norm(Ia1);
    err_TEMF(i) = norm(I_2 - Ia2)/norm(Ia2); 
    
    [I_3,sigma_3,phi_3,t_TMEF(i),iter_TMEF(i)]=tm_wave_EFIE(2*lambda,nodes(i),f,'conjgr');
    [Ia_2,bsew_2]=tm_analytical(2*lambda,phi_3, f); 

    err_TMEF(i) = norm(I_3 - Ia_2)/norm(Ia_2);    
end

%Also record the time of direct solver
for i=1:N
    [I_1,sigma_1,phi_1,t_TEEFD(i),iter_1]=te_wave_EFIE(2*lambda,nodes(i),f,'direct');
    [I_2,sigma_2,phi_2,t_TEMFD(i),iter_2]=te_wave_MFIE(2*lambda,nodes(i),f,'direct');    
    [I_3,sigma_3,phi_3,t_TMEFD(i),iter_3]=tm_wave_EFIE(2*lambda,nodes(i),f,'direct'); 
end

save TestAccuracyNodes.mat;

myPlot2=figure;
plot(nodes, err_TEEF, '-or');
hold on
plot(nodes, err_TEMF, '-+b');
hold on
plot(nodes, err_TMEF, '-*k');
set(gca, 'YScale','log');
set(gca, 'XScale','log');
xlabel('Number of nodes')
ylabel('Error')
legend('TE EFIE','TE MFIE', 'TM EFIE')
set(myPlot2,'Position',[400, 400,400,250])
grid on

myPlot3=figure;
plot(nodes, iter_TEEF, '-or');
hold on
plot(nodes, iter_TEMF, '-+b');
hold on
plot(nodes, iter_TMEF, '-*k');
set(gca, 'YScale','log');
set(gca, 'XScale','log');
xlabel('Number of nodes')
ylabel('Iteration')
legend('TE EFIE','TE MFIE', 'TM EFIE')
set(myPlot3,'Position',[400, 400,400,250])
grid on

myPlot4=figure;
plot(nodes, t_TEEF, '-or');
hold on
plot(nodes, t_TEMF, '-+b');
hold on
plot(nodes, t_TMEF, '-*k');
hold on
plot(nodes, t_TEEFD, '--or');
hold on
plot(nodes, t_TEMFD, '--+b');
hold on
plot(nodes, t_TMEFD, '--*k');
set(gca, 'YScale','log');
set(gca, 'XScale','log');
xlabel('Number of nodes')
ylabel('CPU Time (s)')
legend('TE EFIE FFT','TE MFIE FFT', 'TM EFIE FFT',...
    'TE EFIE direct','TE MFIE direct', 'TM EFIE direct')
set(myPlot4,'Position',[400, 400,400,250])
grid on