%   Test accuracy vs. number of nodes for all solvers
clear
clc
close all;

nodes = 201:100:3001;
N = length(nodes);

c=299792458;
f=c*50;
lambda=c/f;

t_TEEF_s = zeros(1,N);
t_TEMF_s = zeros(1,N);
t_TMEF_s = zeros(1,N);

t_TEEFD_s = zeros(1,N);
t_TEMFD_s = zeros(1,N);
t_TMEFD_s = zeros(1,N);

iter_TEEF_s = zeros(1,N);
iter_TEMF_s = zeros(1,N);
iter_TMEF_s = zeros(1,N);


%Using conjugate solver to find accuracy
for i=1:N
    [I_1,sigma_1,phi_1,t_TEEF_s(i),iter_TEEF_s(i)]=te_wave_EFIE(2*lambda,nodes(i),f,'conjgr');
    [I_2,sigma_2,phi_2,t_TEMF_s(i),iter_TEMF_s(i)]=te_wave_MFIE(2*lambda,nodes(i),f,'conjgr');    
    [I_3,sigma_3,phi_3,t_TMEF_s(i),iter_TMEF_s(i)]=tm_wave_EFIE(2*lambda,nodes(i),f,'conjgr');  
end

%Also record the time of direct solver
for i=1:N
    [I_1,sigma_1,phi_1,t_TEEFD_s(i),iter_1]=te_wave_EFIE(2*lambda,nodes(i),f,'direct');
    [I_2,sigma_2,phi_2,t_TEMFD_s(i),iter_2]=te_wave_MFIE(2*lambda,nodes(i),f,'direct');    
    [I_3,sigma_3,phi_3,t_TMEFD_s(i),iter_3]=tm_wave_EFIE(2*lambda,nodes(i),f,'direct'); 
end

save TestSquareTime.mat;

myPlot3=figure;
plot(nodes, iter_TEEF_s, '-or');
hold on
plot(nodes, iter_TEMF_s, '-+b');
hold on
plot(nodes, iter_TMEF_s, '-*k');
set(gca, 'YScale','log');
set(gca, 'XScale','log');
xlabel('Number of nodes')
ylabel('Iteration')
legend('TE EFIE','TE MFIE', 'TM EFIE')
set(myPlot3,'Position',[400, 400,400,250])
grid on

myPlot4=figure;
plot(nodes, t_TEEF_s, '-or');
hold on
plot(nodes, t_TEMF_s, '-+b');
hold on
plot(nodes, t_TMEF_s, '-*k');
hold on
plot(nodes, t_TEEFD_s, '--or');
hold on
plot(nodes, t_TEMFD_s, '--+b');
hold on
plot(nodes, t_TMEFD_s, '--*k');
set(gca, 'YScale','log');
set(gca, 'XScale','log');
xlim([200 3000])
xlabel('Number of nodes')
ylabel('CPU Time (s)')
legend('TE EFIE QMR','TE MFIE QMR', 'TM EFIE QMR',...
    'TE EFIE direct','TE MFIE direct', 'TM EFIE direct')
set(myPlot4,'Position',[400, 400,400,250])
grid on